> [!NOTE]
> If there are missing Ref Types missing from Ledger please let me know\
> I don't know any Ref Type and there is no Website to look at

# PvE

- **Bounty**
  - bounty_prizes
- **ESS**
  - ess_escrow_transfer
- **Mission**
  - agent_mission_reward
  - agent_mission_time_bonus_reward
- **Incursion**
  - corporate_reward_payout
- **Daily Goal**
  - daily_goal_reward

<hr>

# Character Ledger

## Costs

- **Contract**

  - contract_price
  - contract_collateral
  - contract_reward_deposited
  - contract_brokers_fee
  - contract_sales_tax

- **Market**

  - market_escrow
  - transaction_tax
  - market_provider_tax
  - brokers_fee

- **Assets**

  - asset_safety_recovery_tax

- **Traveling**

  - structure_gate_jump
  - jump_clone_activation_fee
  - jump_clone_installation_fee

- **Production**

  - industry_job_tax
  - manufacturing
  - researching_time_productivity
  - researching_material_productivity
  - copying
  - reprocessing_tax
  - reaction

- **Skill**

  - skill_purchase

- **Insurance**

  - insurance

- **Planetary**

  - planetary_export_tax
  - planetary_import_tax
  - planetary_construction

- **LP**

  - lp_store

<hr>

## Income

- **Market**

  - market_transaction
  - market_escrow

- **Contract**

  - contract_price_payment_corp
  - contract_reward
  - contract_price
  - contract_reward_refund
  - contract_collateral_refund
  - contract_deposit_refund

- **Donation**

  - player_donation

- **Insurance**

  - insurance

- **Mile Stone Reward**

  - milestone_reward_payment

# Corporation Ledger

# Income

- **Citadel**

  - industry_job_tax
  - reprocessing_tax
